"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const table_1 = require("table");
const logSymbols = require("log-symbols");
const chalk_1 = require("chalk");
function renderTable(rawResults = []) {
    let results = rawResults.map(item => {
        const { bin, semver, installed, version, satisfies, optional } = item;
        const pass = satisfies
            ? `${logSymbols.success} ${chalk_1.default.dim('OK')}`
            : optional
                ? `${logSymbols.warning} ${chalk_1.default.dim('NOK (optional)')}`
                : `${logSymbols.error} ${chalk_1.default.dim('NOK')}`;
        return {
            bin: optional ? chalk_1.default.dim(`${bin}`) : bin,
            semver: chalk_1.default.dim(semver),
            version: installed ? chalk_1.default.dim(version) : chalk_1.default.dim('not installed'),
            pass
        };
    });
    const tableHeaders = [['software', 'required', 'installed', 'passes']];
    const tableRows = results.map(item => {
        const { bin, semver, version, pass } = item;
        return [bin, semver, version, pass];
    });
    const tableConfig = {
        border: getColouredBorderCharacters('norc', 'dim')
    };
    return table_1.table([...tableHeaders, ...tableRows], tableConfig);
}
exports.renderTable = renderTable;
function getColouredBorderCharacters(name, colour) {
    const result = {};
    const borderChars = table_1.getBorderCharacters(name);
    Object.entries(borderChars)
        .map(([key, val]) => [key, chalk_1.default[colour](val)])
        .forEach(([key, val]) => (result[key] = val));
    return result;
}
